/*
------------------------------------------------------------------------------
 $Revision: 1.1.2.15.4.1 $
 $Date: 2013/06/27 10:26:42 $

 NAME: cxa_oracle_ddl_dds

 TYPE: ucmacro

 DESCRIPTION:
 To create CXA warehouse table or tables.

 SAS VERSION:
 9.3

 INPUT:
 Specify data sets, files, reports, graphs, html, e-mail, pages,               
 macro variables, slists, return codes, etc.                                   

   +-----------------------------------------------------------------         
   | Input Item Name: tblnm                                                    
   |   Description: Specify ALL to create all tables or a specific table name  
   |   Type:  macro variable                                                   
   |   Default: ALL                                                            
   +-----------------------------------------------------------------          
   | Input Item Name: oracle_connect                                           
   |   Description: oracle database connection information for SQL             
   |                Pass-Thru                                                  
   |   Type:  macro variable                                                   
   |   Default: none                                                           

 OUTPUT:                                                                      
 One or more empty CXA data warehouse tables.                                  

 CALLS:                                                                       
 Specify external software units and how are they called (i.e.                 
 by macros, methods, frames, etc.).                                            

 CALLED BY (optional): %cxa_warehouse_priming                                 

 HISTORY:                                                                     
yyyymmdd defectid desc                                                 
&yyyymmdd &defect  Generated by create_cxa_oracle_ddl_dds.sas
25thJune2013 S0987696 Create script for two log tables 
------------------------------------------------------------------------------ 
 Copyright (c) 2005-2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved
------------------------------------------------------------------------------  
*/                                                                              

%macro cxa_oracle_ddl_dds(tblnm=ALL,                              
                          );                                      

  proc sql noprint;                                               

    &ora_pass_thru_connect                                        

    execute (ALTER SESSION SET NLS_LENGTH_SEMANTICS=CHAR) by oracle;
  %if %upcase(&tblnm) = BROWSER_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                 
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE BROWSER_DIM (                                                                                                                                                                 
    BROWSER_SK           NUMBER(13) NOT NULL,                                                                                                                                                           
    BROWSER_NM           VARCHAR2(52),                                                                                                                                                                  
    BROWSER_VERSION_NO   VARCHAR2(16),                                                                                                                                                                  
    PRIMARY KEY (BROWSER_SK)                                                                                                                                                                            
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = BUSINESS_PROCESS_EXCEPTION_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE BUSINESS_PROCESS_EXCEPTION_DIM (                                                                                                                                              
    PROCESS_EXCEPTION_SK NUMBER(13) NOT NULL,                                                                                                                                                           
    PROCESS_EXCEPTION_TXT VARCHAR2(1300),                                                                                                                                                               
    PRIMARY KEY (PROCESS_EXCEPTION_SK)                                                                                                                                                                  
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = BUSINESS_PROCESS_STEP_DETAILS or %upcase(&tblnm) = ALL %then %do;                                                                                                               
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE BUSINESS_PROCESS_STEP_DETAILS (                                                                                                                                               
    BUS_PROCESS_STEP_DETAILS_SK NUMBER(13) NOT NULL,                                                                                                                                                    
    ATTRIBUTE1_TXT       VARCHAR2(130),                                                                                                                                                                 
    ATTRIBUTE2_TXT       VARCHAR2(130),                                                                                                                                                                 
    DETAIL_SK            NUMBER(22),                                                                                                                                                                    
    IS_COMPLETION_FLG    CHAR(1),                                                                                                                                                                       
    IS_START_FLG         CHAR(1),                                                                                                                                                                       
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    NEXT_DETAIL_SK       NUMBER(22),                                                                                                                                                                    
    PROCESS_DTTM         TIMESTAMP,                                                                                                                                                                     
    PROCESS_ATTEMPT_CNT  NUMBER(3),                                                                                                                                                                     
    PROCESS_INSTANCE_NO  NUMBER(3),                                                                                                                                                                     
    PROCESS_STEP_SK      NUMBER(13) NOT NULL,                                                                                                                                                           
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    STEP_ORDER_NO        NUMBER(3),                                                                                                                                                                     
    PRIMARY KEY                                                                                                                                                                                         
    (BUS_PROCESS_STEP_DETAILS_SK)                                                                                                                                                                       
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF2BUSINESS_PROCESS_STEP_DETA ON                                                                                                                                             
    BUSINESS_PROCESS_STEP_DETAILS( PROCESS_STEP_SK )) BY ORACLE;                                                                                                                                        
    EXECUTE (CREATE INDEX XIF4BUSINESS_PROCESS_STEP_DETA ON                                                                                                                                             
    BUSINESS_PROCESS_STEP_DETAILS( NEXT_DETAIL_SK )) BY ORACLE;                                                                                                                                         
    EXECUTE (CREATE INDEX XIF5BUSINESS_PROCESS_STEP_DETA ON                                                                                                                                             
    BUSINESS_PROCESS_STEP_DETAILS( SESSION_SK )) BY ORACLE;                                                                                                                                             
    EXECUTE (CREATE INDEX XIF6BUSINESS_PROCESS_STEP_DETA ON                                                                                                                                             
    BUSINESS_PROCESS_STEP_DETAILS( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                 
    EXECUTE (CREATE INDEX XIF7BUSINESS_PROCESS_STEP_DETA ON                                                                                                                                             
    BUSINESS_PROCESS_STEP_DETAILS( DETAIL_SK )) BY ORACLE;                                                                                                                                              
    EXECUTE (CREATE INDEX XIE1BUSINESS_PROCESS_STEP_DETA ON                                                                                                                                             
    BUSINESS_PROCESS_STEP_DETAILS( LOAD_DTTM )) BY ORACLE;                                                                                                                                              
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = BUSINESS_PROCESS_STEP_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                   
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE BUSINESS_PROCESS_STEP_DIM (                                                                                                                                                   
    PROCESS_STEP_SK      NUMBER(13) NOT NULL,                                                                                                                                                           
    PROCESS_NM           VARCHAR2(130),                                                                                                                                                                 
    PROCESS_STEP_NM      VARCHAR2(130),                                                                                                                                                                 
    PRIMARY KEY (PROCESS_STEP_SK)                                                                                                                                                                       
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = BUSINESS_PROCESS_X_EXCEPTION or %upcase(&tblnm) = ALL %then %do;                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE BUSINESS_PROCESS_X_EXCEPTION (                                                                                                                                                
    PROCESS_EXCEPTION_SK NUMBER(13) NOT NULL,                                                                                                                                                           
    PROCESS_EXCEPTION_DTTM TIMESTAMP NOT NULL,                                                                                                                                                          
    BUS_PROCESS_STEP_DETAILS_SK NUMBER(13) NOT NULL,                                                                                                                                                    
    PROCESS_STEP_SK      NUMBER(13) NOT NULL,                                                                                                                                                           
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    DETAIL_SK            NUMBER(22),                                                                                                                                                                    
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    UNSUCCESSFUL_ATTEMPT_INDEX_NO NUMBER(3),                                                                                                                                                            
    PRIMARY KEY (PROCESS_EXCEPTION_SK,                                                                                                                                                                  
    PROCESS_EXCEPTION_DTTM, BUS_PROCESS_STEP_DETAILS_SK)                                                                                                                                                
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1BUSINESS_PROCESS_X_EXCEPTI ON                                                                                                                                             
    BUSINESS_PROCESS_X_EXCEPTION( PROCESS_EXCEPTION_SK )) BY ORACLE;                                                                                                                                    
    EXECUTE (CREATE INDEX XIF2BUSINESS_PROCESS_X_EXCEPTI ON                                                                                                                                             
    BUSINESS_PROCESS_X_EXCEPTION( PROCESS_STEP_SK )) BY ORACLE;                                                                                                                                         
    EXECUTE (CREATE INDEX XIF4BUSINESS_PROCESS_X_EXCEPTI ON                                                                                                                                             
    BUSINESS_PROCESS_X_EXCEPTION( SESSION_SK )) BY ORACLE;                                                                                                                                              
    EXECUTE (CREATE INDEX XIF5BUSINESS_PROCESS_X_EXCEPTI ON                                                                                                                                             
    BUSINESS_PROCESS_X_EXCEPTION( BUS_PROCESS_STEP_DETAILS_SK )) BY ORACLE;                                                                                                                             
    EXECUTE (CREATE INDEX XIF6BUSINESS_PROCESS_X_EXCEPTI ON                                                                                                                                             
    BUSINESS_PROCESS_X_EXCEPTION( DETAIL_SK )) BY ORACLE;                                                                                                                                               
    EXECUTE (CREATE INDEX XIE1BUSINESS_PROCESS_X_EXCEPTI ON                                                                                                                                             
    BUSINESS_PROCESS_X_EXCEPTION( LOAD_DTTM )) BY ORACLE;                                                                                                                                               
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = CART_ACTIVITY_DETAIL_FACT or %upcase(&tblnm) = ALL %then %do;                                                                                                                   
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE CART_ACTIVITY_DETAIL_FACT (                                                                                                                                                   
    ACTIVITY_DTTM        TIMESTAMP NOT NULL,                                                                                                                                                            
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    PRODUCT_SK           NUMBER(13) NOT NULL,                                                                                                                                                           
    ACTIVITY_CD          VARCHAR2(20),                                                                                                                                                                  
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    QUANTITY_VAL         NUMBER(9),                                                                                                                                                                     
    SESSION_ATTRIBUTION_SK NUMBER(19) NOT NULL,                                                                                                                                                         
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    UNIT_PRICE_AMT       NUMBER(17,2),                                                                                                                                                                  
    PRIMARY KEY (ACTIVITY_DTTM, DETAIL_SK,                                                                                                                                                              
    PRODUCT_SK)                                                                                                                                                                                         
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1CART_ACTIVITY_DETAIL_FACT ON                                                                                                                                              
    CART_ACTIVITY_DETAIL_FACT( DETAIL_SK )) BY ORACLE;                                                                                                                                                  
    EXECUTE (CREATE INDEX XIF2CART_ACTIVITY_DETAIL_FACT ON                                                                                                                                              
    CART_ACTIVITY_DETAIL_FACT( PRODUCT_SK )) BY ORACLE;                                                                                                                                                 
    EXECUTE (CREATE INDEX XIF3CART_ACTIVITY_DETAIL_FACT ON                                                                                                                                              
    CART_ACTIVITY_DETAIL_FACT( SESSION_SK )) BY ORACLE;                                                                                                                                                 
    EXECUTE (CREATE INDEX XIF4CART_ACTIVITY_DETAIL_FACT ON                                                                                                                                              
    CART_ACTIVITY_DETAIL_FACT( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                     
    EXECUTE (CREATE INDEX XIE1CART_ACTIVITY_DETAIL_FACT ON                                                                                                                                              
    CART_ACTIVITY_DETAIL_FACT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                  
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = CI_RESPONSE_LINK or %upcase(&tblnm) = ALL %then %do;                                                                                                                            
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE CI_RESPONSE_LINK (                                                                                                                                                            
    CI_RESPONSE_SK       NUMBER(13) NOT NULL,                                                                                                                                                           
    ENTRY_SOURCE_ID      VARCHAR2(10),                                                                                                                                                                  
    RESPONSE_TRACKING_CD VARCHAR2(14),                                                                                                                                                                  
    SUBJECT1_ID_VAL      VARCHAR2(32),                                                                                                                                                                  
    SUBJECT2_ID_VAL      VARCHAR2(32),                                                                                                                                                                  
    SUBJECT3_ID_VAL      VARCHAR2(32),                                                                                                                                                                  
    SUBJECT4_ID_VAL      VARCHAR2(32),                                                                                                                                                                  
    SUBJECT5_ID_VAL      VARCHAR2(32),                                                                                                                                                                  
    TREATMENT_TRACKING_CD VARCHAR2(32),                                                                                                                                                                 
    PRIMARY KEY (CI_RESPONSE_SK)                                                                                                                                                                        
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = CUSTOMER_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE CUSTOMER_DIM (                                                                                                                                                                
    CUSTOMER_SK          NUMBER(13) NOT NULL,                                                                                                                                                           
    ACCOUNT_ID           VARCHAR2(40),                                                                                                                                                                  
    ADDRESS_LINE1_TXT    VARCHAR2(100),                                                                                                                                                                 
    ADDRESS_LINE2_TXT    VARCHAR2(100),                                                                                                                                                                 
    ADDRESS_LINE3_TXT    VARCHAR2(100),                                                                                                                                                                 
    ADDRESS_LINE4_TXT    VARCHAR2(100),                                                                                                                                                                 
    BUSINESS_EMAIL_TXT   VARCHAR2(40),                                                                                                                                                                  
    CITY_NM              VARCHAR2(40),                                                                                                                                                                  
    COMPANY_NM           VARCHAR2(40),                                                                                                                                                                  
    COOKIE_ONLY_FLG      VARCHAR2(1),                                                                                                                                                                   
    COUNTRY_NM           VARCHAR2(40),                                                                                                                                                                  
    DAYTIME_PHONE_NO     VARCHAR2(20),                                                                                                                                                                  
    DATE_OF_BIRTH        VARCHAR2(10),                                                                                                                                                                  
    EVENING_PHONE_NO     VARCHAR2(20),                                                                                                                                                                  
    FIRST_NM             VARCHAR2(40),                                                                                                                                                                  
    GENDER_CD            VARCHAR2(1),                                                                                                                                                                   
    INDUSTRY_NM          VARCHAR2(25),                                                                                                                                                                  
    LAST_NM              VARCHAR2(40),                                                                                                                                                                  
    MIDDLE_NM            VARCHAR2(40),                                                                                                                                                                  
    MOBILE_PHONE_NO      VARCHAR2(20),                                                                                                                                                                  
    POSTAL_CD            VARCHAR2(10),                                                                                                                                                                  
    PRIMARY_EMAIL_TXT    VARCHAR2(40),                                                                                                                                                                  
    PRIVATE_EMAIL_TXT    VARCHAR2(40),                                                                                                                                                                  
    STATE_REGION_NM      VARCHAR2(20),                                                                                                                                                                  
    TITLE_NM             VARCHAR2(20),                                                                                                                                                                  
    USER_ID              VARCHAR2(128),                                                                                                                                                                 
    PRIMARY KEY (CUSTOMER_SK)                                                                                                                                                                           
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = CXA_CUSTOM_ATTRIBUTES or %upcase(&tblnm) = ALL %then %do;                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE CXA_CUSTOM_ATTRIBUTES (                                                                                                                                                       
    ATTRIB_DTTM          TIMESTAMP,                                                                                                                                                                     
    ATTRIB_NM            VARCHAR2(32),                                                                                                                                                                  
    ATTRIB_VAL           VARCHAR2(650),                                                                                                                                                                 
    DETAIL_SK            NUMBER(22),                                                                                                                                                                    
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    SESSION_ATTRIBUTION_SK NUMBER(19)                                                                                                                                                                   
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIE1CXA_CUSTOM_ATTRIBUTES ON                                                                                                                                                  
    CXA_CUSTOM_ATTRIBUTES( LOAD_DTTM )) BY ORACLE;                                                                                                                                                      
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DATE_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                    
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DATE_DIM (                                                                                                                                                                    
    CAL_DT               DATE NOT NULL,                                                                                                                                                                 
    DAY_IN_CAL_YR_NO     NUMBER(3),                                                                                                                                                                     
    DAY_OF_WEEK_NO       NUMBER(3),                                                                                                                                                                     
    START_OF_MONTH_DT    DATE,                                                                                                                                                                          
    START_OF_QUARTER_DT  DATE,                                                                                                                                                                          
    START_OF_WEEK_DT     DATE,                                                                                                                                                                          
    START_OF_YEAR_DT     DATE,                                                                                                                                                                          
    ETL_FLG              CHAR(1),                                                                                                                                                                       
    PRIMARY KEY (CAL_DT)                                                                                                                                                                                
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DETAIL_FACT or %upcase(&tblnm) = ALL %then %do;                                                                                                                                 
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DETAIL_FACT (                                                                                                                                                                 
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    BYTES_SENT_CNT       NUMBER(9),                                                                                                                                                                     
    DETAIL_DTTM          TIMESTAMP,                                                                                                                                                                     
    DOMAIN_SK            NUMBER(13),                                                                                                                                                                    
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    PAGE_COMPLETE_SEC_CNT NUMBER(11,3),                                                                                                                                                                 
    PAGE_LOAD_SEC_CNT    NUMBER(11,3),                                                                                                                                                                  
    PAGE_SK              NUMBER(13),                                                                                                                                                                    
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    SESSION_DT           DATE,                                                                                                                                                                          
    WINDOW_SIZE_TXT      VARCHAR2(20),                                                                                                                                                                  
    USER_ID              VARCHAR2(52),                                                                                                                                                                  
    PRIMARY KEY (DETAIL_SK)                                                                                                                                                                             
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF0DETAIL_FACT ON                                                                                                                                                            
    DETAIL_FACT( PAGE_SK )) BY ORACLE;                                                                                                                                                                  
    EXECUTE (CREATE INDEX XIF8DETAIL_FACT ON                                                                                                                                                            
    DETAIL_FACT( DOMAIN_SK )) BY ORACLE;                                                                                                                                                                
    EXECUTE (CREATE INDEX DETAIL_FACT_IX ON                                                                                                                                                             
    DETAIL_FACT( SESSION_DT )) BY ORACLE;                                                                                                                                                               
    EXECUTE (CREATE INDEX XIF13DETAIL_FACT ON                                                                                                                                                           
    DETAIL_FACT( SESSION_SK,SESSION_DT )) BY ORACLE;                                                                                                                                                    
    EXECUTE (CREATE INDEX XIF16DETAIL_FACT ON                                                                                                                                                           
    DETAIL_FACT( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                                   
    EXECUTE (CREATE INDEX XIE2DETAIL_FACT ON                                                                                                                                                            
    DETAIL_FACT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                                
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DETAIL_FACT_EXT or %upcase(&tblnm) = ALL %then %do;                                                                                                                             
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DETAIL_FACT_EXT (                                                                                                                                                             
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    LOAD_DTTM            TIMESTAMP NOT NULL,                                                                                                                                                            
    ACTIVE_SEC_SPENT_ON_PAGE_CNT NUMBER(11,3),                                                                                                                                                          
    IS_BROKEN_LINK_FLG   CHAR(1),                                                                                                                                                                       
    SECONDS_SPENT_ON_PAGE_CNT NUMBER(15,3),                                                                                                                                                             
    PRIMARY KEY (DETAIL_SK, LOAD_DTTM)                                                                                                                                                                  
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1DETAIL_FACT_EXT ON                                                                                                                                                        
    DETAIL_FACT_EXT( DETAIL_SK )) BY ORACLE;                                                                                                                                                            
    EXECUTE (CREATE INDEX XIE1DETAIL_FACT_EXT ON                                                                                                                                                        
    DETAIL_FACT_EXT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                            
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DETAIL_X_DOCUMENT or %upcase(&tblnm) = ALL %then %do;                                                                                                                           
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DETAIL_X_DOCUMENT (                                                                                                                                                           
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    LINK_EVENT_DTTM      TIMESTAMP NOT NULL,                                                                                                                                                            
    DOCUMENT_LOCATION_SK NUMBER(13) NOT NULL,                                                                                                                                                           
    DOCUMENT_SK          NUMBER(13) NOT NULL,                                                                                                                                                           
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    PRIMARY KEY (DETAIL_SK, LINK_EVENT_DTTM,                                                                                                                                                            
    DOCUMENT_LOCATION_SK, DOCUMENT_SK)                                                                                                                                                                  
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1DETAIL_X_DOCUMENT ON                                                                                                                                                      
    DETAIL_X_DOCUMENT( DETAIL_SK )) BY ORACLE;                                                                                                                                                          
    EXECUTE (CREATE INDEX XIF3DETAIL_X_DOCUMENT ON                                                                                                                                                      
    DETAIL_X_DOCUMENT( SESSION_SK )) BY ORACLE;                                                                                                                                                         
    EXECUTE (CREATE INDEX XIF4DETAIL_X_DOCUMENT ON                                                                                                                                                      
    DETAIL_X_DOCUMENT( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                             
    EXECUTE (CREATE INDEX XIF5DETAIL_X_DOCUMENT ON                                                                                                                                                      
    DETAIL_X_DOCUMENT( DOCUMENT_LOCATION_SK )) BY ORACLE;                                                                                                                                               
    EXECUTE (CREATE INDEX XIF6DETAIL_X_DOCUMENT ON                                                                                                                                                      
    DETAIL_X_DOCUMENT( DOCUMENT_SK )) BY ORACLE;                                                                                                                                                        
    EXECUTE (CREATE INDEX XIE1DETAIL_X_DOCUMENT ON                                                                                                                                                      
    DETAIL_X_DOCUMENT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                          
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DETAIL_X_INT_PROMOTION_DISPLAY or %upcase(&tblnm) = ALL %then %do;                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DETAIL_X_INT_PROMOTION_DISPLAY (                                                                                                                                              
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    PROMOTION_NUMBER     NUMBER(7) NOT NULL,                                                                                                                                                            
    DISPLAY_DTTM         TIMESTAMP NOT NULL,                                                                                                                                                            
    CI_RESPONSE_SK       NUMBER(13),                                                                                                                                                                    
    DERIVED_DISPLAY_FLG  CHAR(1),                                                                                                                                                                       
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    INTERNAL_PROMOTION_SK NUMBER(13) NOT NULL,                                                                                                                                                          
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    PRIMARY KEY (SESSION_SK,                                                                                                                                                                            
    PROMOTION_NUMBER, DISPLAY_DTTM)                                                                                                                                                                     
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1DETAIL_X_INT_PROMOTION_DIS ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_DISPLAY( DETAIL_SK )) BY ORACLE;                                                                                                                                             
    EXECUTE (CREATE INDEX XIF2DETAIL_X_INT_PROMOTION_DIS ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_DISPLAY( INTERNAL_PROMOTION_SK )) BY ORACLE;                                                                                                                                 
    EXECUTE (CREATE INDEX XIF3DETAIL_X_INT_PROMOTION_DIS ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_DISPLAY( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                
    EXECUTE (CREATE INDEX XIF4DETAIL_X_INT_PROMOTION_DIS ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_DISPLAY( SESSION_SK )) BY ORACLE;                                                                                                                                            
    EXECUTE (CREATE INDEX XIF5DETAIL_X_INT_PROMOTION_DIS ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_DISPLAY( CI_RESPONSE_SK )) BY ORACLE;                                                                                                                                        
    EXECUTE (CREATE INDEX XIE1DETAIL_X_INT_PROMOTION_DIS ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_DISPLAY( DISPLAY_DTTM )) BY ORACLE;                                                                                                                                          
    EXECUTE (CREATE INDEX XIE2DETAIL_X_INT_PROMOTION_DIS ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_DISPLAY( LOAD_DTTM )) BY ORACLE;                                                                                                                                             
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DETAIL_X_INT_PROMOTION_USE or %upcase(&tblnm) = ALL %then %do;                                                                                                                  
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DETAIL_X_INT_PROMOTION_USE (                                                                                                                                                  
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    PROMOTION_NUMBER     NUMBER(7) NOT NULL,                                                                                                                                                            
    CLICK_DTTM           TIMESTAMP NOT NULL,                                                                                                                                                            
    CI_RESPONSE_SK       NUMBER(13),                                                                                                                                                                    
    DETAIL_SK            NUMBER(22),                                                                                                                                                                    
    INTERNAL_PROMOTION_SK NUMBER(13),                                                                                                                                                                   
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    PRIMARY KEY (SESSION_SK,                                                                                                                                                                            
    PROMOTION_NUMBER, CLICK_DTTM)                                                                                                                                                                       
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1DETAIL_X_INT_PROMOTION_USE ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_USE( CI_RESPONSE_SK )) BY ORACLE;                                                                                                                                            
    EXECUTE (CREATE INDEX XIF2DETAIL_X_INT_PROMOTION_USE ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_USE( SESSION_SK )) BY ORACLE;                                                                                                                                                
    EXECUTE (CREATE INDEX XIF3DETAIL_X_INT_PROMOTION_USE ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_USE( DETAIL_SK )) BY ORACLE;                                                                                                                                                 
    EXECUTE (CREATE INDEX XIF4DETAIL_X_INT_PROMOTION_USE ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_USE( INTERNAL_PROMOTION_SK )) BY ORACLE;                                                                                                                                     
    EXECUTE (CREATE INDEX XIF5DETAIL_X_INT_PROMOTION_USE ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_USE( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                    
    EXECUTE (CREATE INDEX XIE1DETAIL_X_INT_PROMOTION_USE ON                                                                                                                                             
    DETAIL_X_INT_PROMOTION_USE( LOAD_DTTM )) BY ORACLE;                                                                                                                                                 
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DETAIL_X_IN_PAGE_ERROR or %upcase(&tblnm) = ALL %then %do;                                                                                                                      
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DETAIL_X_IN_PAGE_ERROR (                                                                                                                                                      
    IN_PAGE_ERROR_SK     NUMBER(13) NOT NULL,                                                                                                                                                           
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    ERROR_LOCATION_TXT   VARCHAR2(21) NOT NULL,                                                                                                                                                         
    IN_PAGE_ERROR_DTTM   TIMESTAMP NOT NULL,                                                                                                                                                            
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    PRIMARY KEY (IN_PAGE_ERROR_SK,                                                                                                                                                                      
    DETAIL_SK, ERROR_LOCATION_TXT, IN_PAGE_ERROR_DTTM)                                                                                                                                                  
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1DETAIL_X_IN_PAGE_ERROR ON                                                                                                                                                 
    DETAIL_X_IN_PAGE_ERROR( IN_PAGE_ERROR_SK )) BY ORACLE;                                                                                                                                              
    EXECUTE (CREATE INDEX XIF2DETAIL_X_IN_PAGE_ERROR ON                                                                                                                                                 
    DETAIL_X_IN_PAGE_ERROR( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                        
    EXECUTE (CREATE INDEX XIF3DETAIL_X_IN_PAGE_ERROR ON                                                                                                                                                 
    DETAIL_X_IN_PAGE_ERROR( DETAIL_SK )) BY ORACLE;                                                                                                                                                     
    EXECUTE (CREATE INDEX XIF4DETAIL_X_IN_PAGE_ERROR ON                                                                                                                                                 
    DETAIL_X_IN_PAGE_ERROR( SESSION_SK )) BY ORACLE;                                                                                                                                                    
    EXECUTE (CREATE INDEX XIE1DETAIL_X_IN_PAGE_ERROR ON                                                                                                                                                 
    DETAIL_X_IN_PAGE_ERROR( LOAD_DTTM )) BY ORACLE;                                                                                                                                                     
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DETAIL_X_PRODUCT or %upcase(&tblnm) = ALL %then %do;                                                                                                                            
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DETAIL_X_PRODUCT (                                                                                                                                                            
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    PRODUCT_SK           NUMBER(13) NOT NULL,                                                                                                                                                           
    ACTION_DTTM          TIMESTAMP NOT NULL,                                                                                                                                                            
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    PRICE_VAL            NUMBER(17,2),                                                                                                                                                                  
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    PRIMARY KEY (DETAIL_SK, PRODUCT_SK,                                                                                                                                                                 
    ACTION_DTTM)                                                                                                                                                                                        
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1DETAIL_X_PRODUCT ON                                                                                                                                                       
    DETAIL_X_PRODUCT( SESSION_SK )) BY ORACLE;                                                                                                                                                          
    EXECUTE (CREATE INDEX XIF2DETAIL_X_PRODUCT ON                                                                                                                                                       
    DETAIL_X_PRODUCT( DETAIL_SK )) BY ORACLE;                                                                                                                                                           
    EXECUTE (CREATE INDEX XIF3DETAIL_X_PRODUCT ON                                                                                                                                                       
    DETAIL_X_PRODUCT( PRODUCT_SK )) BY ORACLE;                                                                                                                                                          
    EXECUTE (CREATE INDEX XIF4DETAIL_X_PRODUCT ON                                                                                                                                                       
    DETAIL_X_PRODUCT( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                              
    EXECUTE (CREATE INDEX XIE1DETAIL_X_PRODUCT ON                                                                                                                                                       
    DETAIL_X_PRODUCT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                           
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DOCUMENT_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DOCUMENT_DIM (                                                                                                                                                                
    DOCUMENT_SK          NUMBER(13) NOT NULL,                                                                                                                                                           
    URI_TXT              VARCHAR2(1332),                                                                                                                                                                
    ALT_TXT              VARCHAR2(1332),                                                                                                                                                                
    PRIMARY KEY (DOCUMENT_SK)                                                                                                                                                                           
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DOCUMENT_LOCATION_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DOCUMENT_LOCATION_DIM (                                                                                                                                                       
    DOCUMENT_LOCATION_SK NUMBER(13) NOT NULL,                                                                                                                                                           
    LINK_ID              VARCHAR2(1332),                                                                                                                                                                
    LINK_NM              VARCHAR2(1332),                                                                                                                                                                
    PRIMARY KEY (DOCUMENT_LOCATION_SK)                                                                                                                                                                  
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = DOMAIN_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                  
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE DOMAIN_DIM (                                                                                                                                                                  
    DOMAIN_SK            NUMBER(13) NOT NULL,                                                                                                                                                           
    DOMAIN_NM            VARCHAR2(165),                                                                                                                                                                 
    PROTOCOL_NM          VARCHAR2(8),                                                                                                                                                                   
    PORT_NO              NUMBER(6),                                                                                                                                                                     
    DOMAIN_TYPE_CD       VARCHAR2(1),                                                                                                                                                                   
    PRIMARY KEY (DOMAIN_SK)                                                                                                                                                                             
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = FORM_DETAIL or %upcase(&tblnm) = ALL %then %do;                                                                                                                                 
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE FORM_DETAIL (                                                                                                                                                                 
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    FORM_FIELD_SK        NUMBER(13) NOT NULL,                                                                                                                                                           
    ATTEMPT_INDEX_CNT    NUMBER(4) NOT NULL,                                                                                                                                                            
    ATTEMPT_STATUS_CD    VARCHAR2(42) NOT NULL,                                                                                                                                                         
    CHANGE_INDEX_NO      NUMBER(3) NOT NULL,                                                                                                                                                            
    SUBMIT_FLG           VARCHAR2(1) NOT NULL,                                                                                                                                                          
    FORM_FIELD_DETAIL_DTTM TIMESTAMP NOT NULL,                                                                                                                                                          
    FORM_FIELD_VALUE     VARCHAR2(2600),                                                                                                                                                                
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    NEXT_DETAIL_SK       NUMBER(22),                                                                                                                                                                    
    SEARCH_RESULTS_SK    NUMBER(13),                                                                                                                                                                    
    SESSION_ATTRIBUTION_SK NUMBER(19) NOT NULL,                                                                                                                                                         
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    PRIMARY KEY (DETAIL_SK, FORM_FIELD_SK,                                                                                                                                                              
    ATTEMPT_INDEX_CNT, ATTEMPT_STATUS_CD, CHANGE_INDEX_NO, SUBMIT_FLG,                                                                                                                                  
    FORM_FIELD_DETAIL_DTTM)                                                                                                                                                                             
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF2FORM_DETAIL ON                                                                                                                                                            
    FORM_DETAIL( SESSION_SK )) BY ORACLE;                                                                                                                                                               
    EXECUTE (CREATE INDEX XIF3FORM_DETAIL ON                                                                                                                                                            
    FORM_DETAIL( DETAIL_SK )) BY ORACLE;                                                                                                                                                                
    EXECUTE (CREATE INDEX XIF4FORM_DETAIL ON                                                                                                                                                            
    FORM_DETAIL( FORM_FIELD_SK )) BY ORACLE;                                                                                                                                                            
    EXECUTE (CREATE INDEX XIF5FORM_DETAIL ON                                                                                                                                                            
    FORM_DETAIL( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                                   
    EXECUTE (CREATE INDEX XIF8FORM_DETAIL ON                                                                                                                                                            
    FORM_DETAIL( SEARCH_RESULTS_SK )) BY ORACLE;                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF9FORM_DETAIL ON                                                                                                                                                            
    FORM_DETAIL( NEXT_DETAIL_SK )) BY ORACLE;                                                                                                                                                           
    EXECUTE (CREATE INDEX XIE1FORM_DETAIL ON                                                                                                                                                            
    FORM_DETAIL( LOAD_DTTM )) BY ORACLE;                                                                                                                                                                
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = FORM_FIELD_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE FORM_FIELD_DIM (                                                                                                                                                              
    FORM_FIELD_SK        NUMBER(13) NOT NULL,                                                                                                                                                           
    FORM_FIELD_NM        VARCHAR2(325),                                                                                                                                                                 
    FORM_NM              VARCHAR2(65),                                                                                                                                                                  
    PRIMARY KEY (FORM_FIELD_SK)                                                                                                                                                                         
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = GEO_IP_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                  
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE GEO_IP_DIM (                                                                                                                                                                  
    GEO_IP_SK            NUMBER(13) NOT NULL,                                                                                                                                                           
    CITY_NM              VARCHAR2(390),                                                                                                                                                                 
    COUNTRY_CD           VARCHAR2(2),                                                                                                                                                                   
    COUNTRY_NM           VARCHAR2(85),                                                                                                                                                                  
    LATITUDE             VARCHAR2(13),                                                                                                                                                                  
    LONGITUDE            VARCHAR2(13),                                                                                                                                                                  
    METRO_CD             NUMBER(13),                                                                                                                                                                    
    ORGANIZATION_NM      VARCHAR2(256),                                                                                                                                                                 
    REGION_NM            VARCHAR2(256),                                                                                                                                                                 
    STATE_REGION_CD      VARCHAR2(2),                                                                                                                                                                   
    PRIMARY KEY (GEO_IP_SK)                                                                                                                                                                             
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX GEO_IP_DIM_IX ON                                                                                                                                                              
    GEO_IP_DIM( COUNTRY_CD,STATE_REGION_CD,LATITUDE,LONGITUDE,METRO_CD,CITY_NM )) BY ORACLE;                                                                                                            
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = GOAL_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                    
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE GOAL_DIM (                                                                                                                                                                    
    GOAL_SK              NUMBER(13) NOT NULL,                                                                                                                                                           
    GOAL_GROUP_NM        VARCHAR2(130),                                                                                                                                                                 
    GOAL_NM              VARCHAR2(260),                                                                                                                                                                 
    PRIMARY KEY (GOAL_SK)                                                                                                                                                                               
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = GOAL_X_SESSION or %upcase(&tblnm) = ALL %then %do;                                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE GOAL_X_SESSION (                                                                                                                                                              
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    GOAL_SK              NUMBER(13) NOT NULL,                                                                                                                                                           
    GOAL_REACHED_DTTM    TIMESTAMP NOT NULL,                                                                                                                                                            
    GOAL_REVENUE_AMT     NUMBER(17,2),                                                                                                                                                                  
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    PRIMARY KEY (DETAIL_SK, GOAL_SK,                                                                                                                                                                    
    GOAL_REACHED_DTTM)                                                                                                                                                                                  
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1GOAL_X_SESSION ON                                                                                                                                                         
    GOAL_X_SESSION( GOAL_SK )) BY ORACLE;                                                                                                                                                               
    EXECUTE (CREATE INDEX XIF2GOAL_X_SESSION ON                                                                                                                                                         
    GOAL_X_SESSION( SESSION_SK )) BY ORACLE;                                                                                                                                                            
    EXECUTE (CREATE INDEX XIF3GOAL_X_SESSION ON                                                                                                                                                         
    GOAL_X_SESSION( DETAIL_SK )) BY ORACLE;                                                                                                                                                             
    EXECUTE (CREATE INDEX XIF4GOAL_X_SESSION ON                                                                                                                                                         
    GOAL_X_SESSION( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                                
    EXECUTE (CREATE INDEX XIE1GOAL_X_SESSION ON                                                                                                                                                         
    GOAL_X_SESSION( LOAD_DTTM )) BY ORACLE;                                                                                                                                                             
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = INTERNAL_PROMOTION_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                      
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE INTERNAL_PROMOTION_DIM (                                                                                                                                                      
    INTERNAL_PROMOTION_SK NUMBER(13) NOT NULL,                                                                                                                                                          
    PROMOTION_NM         VARCHAR2(260),                                                                                                                                                                 
    PROMOTION_TRACKING_CD VARCHAR2(65),                                                                                                                                                                 
    PROMOTION_TYPE_NM    VARCHAR2(65),                                                                                                                                                                  
    PROMOTION_PLACEMENT_NM VARCHAR2(260),                                                                                                                                                               
    PROMOTION_CREATIVE_NM VARCHAR2(260),                                                                                                                                                                
    PRIMARY KEY (INTERNAL_PROMOTION_SK)                                                                                                                                                                 
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = IN_PAGE_ERROR_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                           
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE IN_PAGE_ERROR_DIM (                                                                                                                                                           
    IN_PAGE_ERROR_SK     NUMBER(13) NOT NULL,                                                                                                                                                           
    IN_PAGE_ERROR_TXT    VARCHAR2(260),                                                                                                                                                                 
    PRIMARY KEY (IN_PAGE_ERROR_SK)                                                                                                                                                                      
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = LOAD_HISTORY or %upcase(&tblnm) = ALL %then %do;                                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE LOAD_HISTORY (                                                                                                                                                                
    EVENT_NO             NUMBER(8),                                                                                                                                                                     
    LOAD_NO              NUMBER(8),                                                                                                                                                                     
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    BEGIN_SAMPLE_TS_5MIN_MS NUMBER(30),                                                                                                                                                                 
    END_SAMPLE_TS_5MIN_MS NUMBER(30),                                                                                                                                                                   
    BEGIN_SAMPLE_TS_HR_MS NUMBER(30),                                                                                                                                                                   
    END_SAMPLE_TS_HR_MS  NUMBER(30),                                                                                                                                                                    
    RESULT_TXT           VARCHAR2(25)                                                                                                                                                                   
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIE1LOAD_HISTORY ON                                                                                                                                                           
    LOAD_HISTORY( EVENT_NO )) BY ORACLE;                                                                                                                                                                
    EXECUTE (CREATE INDEX XIE2LOAD_HISTORY ON                                                                                                                                                           
    LOAD_HISTORY( LOAD_NO )) BY ORACLE;                                                                                                                                                                 
    EXECUTE (CREATE INDEX XIE3LOAD_HISTORY ON                                                                                                                                                           
    LOAD_HISTORY( RESULT_TXT )) BY ORACLE;                                                                                                                                                              
    EXECUTE (CREATE INDEX XIE4LOAD_HISTORY ON                                                                                                                                                           
    LOAD_HISTORY( LOAD_DTTM )) BY ORACLE;                                                                                                                                                               
    EXECUTE (CREATE INDEX XIE5LOAD_HISTORY ON                                                                                                                                                           
    LOAD_HISTORY( BEGIN_SAMPLE_TS_5MIN_MS )) BY ORACLE;                                                                                                                                                 
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = MEDIA_DETAIL or %upcase(&tblnm) = ALL %then %do;                                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE MEDIA_DETAIL (                                                                                                                                                                
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    MEDIA_SK             NUMBER(13) NOT NULL,                                                                                                                                                           
    START_TM             NUMBER(11,3) NOT NULL,                                                                                                                                                         
    END_TM               NUMBER(11,3),                                                                                                                                                                  
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    PRIMARY KEY (DETAIL_SK, MEDIA_SK,                                                                                                                                                                   
    START_TM)                                                                                                                                                                                           
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1MEDIA_DETAIL ON                                                                                                                                                           
    MEDIA_DETAIL( DETAIL_SK )) BY ORACLE;                                                                                                                                                               
    EXECUTE (CREATE INDEX XIF2MEDIA_DETAIL ON                                                                                                                                                           
    MEDIA_DETAIL( MEDIA_SK )) BY ORACLE;                                                                                                                                                                
    EXECUTE (CREATE INDEX XIE1MEDIA_DETAIL ON                                                                                                                                                           
    MEDIA_DETAIL( LOAD_DTTM )) BY ORACLE;                                                                                                                                                               
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = MEDIA_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                   
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE MEDIA_DIM (                                                                                                                                                                   
    MEDIA_SK             NUMBER(13) NOT NULL,                                                                                                                                                           
    MEDIA_DURATION_SECS  NUMBER(11,3),                                                                                                                                                                  
    MEDIA_NM             VARCHAR2(260),                                                                                                                                                                 
    MEDIA_URI_TXT        VARCHAR2(2024),                                                                                                                                                                
    PRIMARY KEY (MEDIA_SK)                                                                                                                                                                              
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = MEDIA_PLAYER_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                            
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE MEDIA_PLAYER_DIM (                                                                                                                                                            
    MEDIA_PLAYER_SK      NUMBER(13) NOT NULL,                                                                                                                                                           
    MEDIA_PLAYER_NM      VARCHAR2(30),                                                                                                                                                                  
    MEDIA_PLAYER_VERSION_TXT VARCHAR2(20),                                                                                                                                                              
    PRIMARY KEY (MEDIA_PLAYER_SK)                                                                                                                                                                       
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = MEDIA_X_SESSION or %upcase(&tblnm) = ALL %then %do;                                                                                                                             
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE MEDIA_X_SESSION (                                                                                                                                                             
    DETAIL_SK            NUMBER(22) NOT NULL,                                                                                                                                                           
    MEDIA_SK             NUMBER(13) NOT NULL,                                                                                                                                                           
    EXIT_POINT_SECS      NUMBER(11,3),                                                                                                                                                                  
    INTERACTION_CNT      NUMBER(3),                                                                                                                                                                     
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    MAX_PLAY_SECS        NUMBER(11,3),                                                                                                                                                                  
    MEDIA_DISPLAY_DURATION_SECS NUMBER(11,3),                                                                                                                                                           
    MEDIA_PLAYER_SK      NUMBER(13),                                                                                                                                                                    
    PLAY_END_DTTM        TIMESTAMP,                                                                                                                                                                     
    PLAY_START_DTTM      TIMESTAMP,                                                                                                                                                                     
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    VIEW_DURATION_SECS   NUMBER(11,3),                                                                                                                                                                  
    PRIMARY KEY (DETAIL_SK, MEDIA_SK)                                                                                                                                                                   
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1MEDIA_X_SESSION ON                                                                                                                                                        
    MEDIA_X_SESSION( SESSION_SK )) BY ORACLE;                                                                                                                                                           
    EXECUTE (CREATE INDEX XIF2MEDIA_X_SESSION ON                                                                                                                                                        
    MEDIA_X_SESSION( DETAIL_SK )) BY ORACLE;                                                                                                                                                            
    EXECUTE (CREATE INDEX XIF3MEDIA_X_SESSION ON                                                                                                                                                        
    MEDIA_X_SESSION( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                               
    EXECUTE (CREATE INDEX XIF4MEDIA_X_SESSION ON                                                                                                                                                        
    MEDIA_X_SESSION( MEDIA_SK )) BY ORACLE;                                                                                                                                                             
    EXECUTE (CREATE INDEX XIF5MEDIA_X_SESSION ON                                                                                                                                                        
    MEDIA_X_SESSION( MEDIA_PLAYER_SK )) BY ORACLE;                                                                                                                                                      
    EXECUTE (CREATE INDEX XIE1MEDIA_X_SESSION ON                                                                                                                                                        
    MEDIA_X_SESSION( LOAD_DTTM )) BY ORACLE;                                                                                                                                                            
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = ORDER_DETAIL_FACT or %upcase(&tblnm) = ALL %then %do;                                                                                                                           
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE ORDER_DETAIL_FACT (                                                                                                                                                           
    ORDER_DETAIL_SK      NUMBER(13) NOT NULL,                                                                                                                                                           
    CURRENCY_CD          VARCHAR2(6),                                                                                                                                                                   
    DETAIL_SK            NUMBER(22),                                                                                                                                                                    
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    ORDER_SUMMARY_SK     NUMBER(13),                                                                                                                                                                    
    PRODUCT_SK           NUMBER(13),                                                                                                                                                                    
    QUANTITY_AMT         NUMBER(9),                                                                                                                                                                     
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    UNIT_PRICE_AMT       NUMBER(17,2),                                                                                                                                                                  
    PRIMARY KEY (ORDER_DETAIL_SK)                                                                                                                                                                       
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF4ORDER_DETAIL_FACT ON                                                                                                                                                      
    ORDER_DETAIL_FACT( ORDER_SUMMARY_SK )) BY ORACLE;                                                                                                                                                   
    EXECUTE (CREATE INDEX XIF5ORDER_DETAIL_FACT ON                                                                                                                                                      
    ORDER_DETAIL_FACT( DETAIL_SK )) BY ORACLE;                                                                                                                                                          
    EXECUTE (CREATE INDEX XIF6ORDER_DETAIL_FACT ON                                                                                                                                                      
    ORDER_DETAIL_FACT( PRODUCT_SK )) BY ORACLE;                                                                                                                                                         
    EXECUTE (CREATE INDEX XIF9ORDER_DETAIL_FACT ON                                                                                                                                                      
    ORDER_DETAIL_FACT( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                             
    EXECUTE (CREATE INDEX XIF10ORDER_DETAIL_FACT ON                                                                                                                                                     
    ORDER_DETAIL_FACT( SESSION_SK )) BY ORACLE;                                                                                                                                                         
    EXECUTE (CREATE INDEX XIE1ORDER_DETAIL_FACT ON                                                                                                                                                      
    ORDER_DETAIL_FACT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                          
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = ORDER_SUMMARY_FACT or %upcase(&tblnm) = ALL %then %do;                                                                                                                          
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE ORDER_SUMMARY_FACT (                                                                                                                                                          
    ORDER_SUMMARY_SK     NUMBER(13) NOT NULL,                                                                                                                                                           
    ACTIVITY_DTTM        TIMESTAMP,                                                                                                                                                                     
    CHECKOUT_FLG         CHAR(1),                                                                                                                                                                       
    CURRENCY_CD          VARCHAR2(4),                                                                                                                                                                   
    DETAIL_SK            NUMBER(22),                                                                                                                                                                    
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    ITEMS_NO             NUMBER(9),                                                                                                                                                                     
    ORDER_ID             VARCHAR2(42),                                                                                                                                                                  
    PURCHASE_FLG         CHAR(1),                                                                                                                                                                       
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    TOTAL_PRICE_AMT      NUMBER(17,2),                                                                                                                                                                  
    PRIMARY KEY (ORDER_SUMMARY_SK)                                                                                                                                                                      
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1ORDER_SUMMARY_FACT ON                                                                                                                                                     
    ORDER_SUMMARY_FACT( DETAIL_SK )) BY ORACLE;                                                                                                                                                         
    EXECUTE (CREATE INDEX XIF4ORDER_SUMMARY_FACT ON                                                                                                                                                     
    ORDER_SUMMARY_FACT( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                            
    EXECUTE (CREATE INDEX XIF5ORDER_SUMMARY_FACT ON                                                                                                                                                     
    ORDER_SUMMARY_FACT( SESSION_SK )) BY ORACLE;                                                                                                                                                        
    EXECUTE (CREATE INDEX XIE1ORDER_SUMMARY_FACT ON                                                                                                                                                     
    ORDER_SUMMARY_FACT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                         
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = ORIGINATION_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                             
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE ORIGINATION_DIM (                                                                                                                                                             
    ORIGINATION_SK       NUMBER(13) NOT NULL,                                                                                                                                                           
    ORIGINATION_CREATIVE_NM VARCHAR2(260),                                                                                                                                                              
    ORIGINATION_NM       VARCHAR2(260),                                                                                                                                                                 
    ORIGINATION_PLACEMENT_NM VARCHAR2(390),                                                                                                                                                             
    ORIGINATION_TRACKING_CD VARCHAR2(65),                                                                                                                                                               
    ORIGINATION_TYPE_NM  VARCHAR2(65),                                                                                                                                                                  
    PRIMARY KEY (ORIGINATION_SK)                                                                                                                                                                        
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = PAGE_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                    
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE PAGE_DIM (                                                                                                                                                                    
    PAGE_SK              NUMBER(13) NOT NULL,                                                                                                                                                           
    CLASS1_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS2_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS3_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS5_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS4_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS6_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS7_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS8_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS9_ID            VARCHAR2(650),                                                                                                                                                                 
    CLASS10_ID           VARCHAR2(650),                                                                                                                                                                 
    CLASS11_ID           VARCHAR2(650),                                                                                                                                                                 
    CLASS12_ID           VARCHAR2(650),                                                                                                                                                                 
    CLASS13_ID           VARCHAR2(650),                                                                                                                                                                 
    CLASS14_ID           VARCHAR2(650),                                                                                                                                                                 
    CLASS15_ID           VARCHAR2(650),                                                                                                                                                                 
    DOMAIN_SK            NUMBER(13),                                                                                                                                                                    
    PAGE_URL_TXT         VARCHAR2(1332),                                                                                                                                                                
    PAGE_DESC            VARCHAR2(1332),                                                                                                                                                                
    PRIMARY KEY (PAGE_SK)                                                                                                                                                                               
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF2PAGE_DIM ON                                                                                                                                                               
    PAGE_DIM( DOMAIN_SK )) BY ORACLE;                                                                                                                                                                   
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = PLATFORM_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE PLATFORM_DIM (                                                                                                                                                                
    PLATFORM_SK          NUMBER(13) NOT NULL,                                                                                                                                                           
    PLATFORM_DESC        VARCHAR2(78),                                                                                                                                                                  
    PLATFORM_TYPE_NM     VARCHAR2(52),                                                                                                                                                                  
    PRIMARY KEY (PLATFORM_SK)                                                                                                                                                                           
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = PRODUCT_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                 
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE PRODUCT_DIM (                                                                                                                                                                 
    PRODUCT_SK           NUMBER(13) NOT NULL,                                                                                                                                                           
    PRODUCT_ID           VARCHAR2(130),                                                                                                                                                                 
    PRODUCT_GROUP_NM     VARCHAR2(130),                                                                                                                                                                 
    PRODUCT_NM           VARCHAR2(130),                                                                                                                                                                 
    PRODUCT_SKU          VARCHAR2(100),                                                                                                                                                                 
    PRIMARY KEY (PRODUCT_SK)                                                                                                                                                                            
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = PROFILE_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                 
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE PROFILE_DIM (                                                                                                                                                                 
    PROFILE_SK           NUMBER(13) NOT NULL,                                                                                                                                                           
    PROFILE_NM           VARCHAR2(65),                                                                                                                                                                  
    PROFILE_TYPE_NM      VARCHAR2(42),                                                                                                                                                                  
    PRIMARY KEY (PROFILE_SK)                                                                                                                                                                            
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = PROFILE_X_SESSION or %upcase(&tblnm) = ALL %then %do;                                                                                                                           
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE PROFILE_X_SESSION (                                                                                                                                                           
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    PROFILE_SK           NUMBER(13) NOT NULL,                                                                                                                                                           
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    PRIMARY KEY (SESSION_SK, PROFILE_SK)                                                                                                                                                                
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1PROFILE_X_SESSION ON                                                                                                                                                      
    PROFILE_X_SESSION( SESSION_SK )) BY ORACLE;                                                                                                                                                         
    EXECUTE (CREATE INDEX XIF2PROFILE_X_SESSION ON                                                                                                                                                      
    PROFILE_X_SESSION( PROFILE_SK )) BY ORACLE;                                                                                                                                                         
    EXECUTE (CREATE INDEX XIE1PROFILE_X_SESSION ON                                                                                                                                                      
    PROFILE_X_SESSION( LOAD_DTTM )) BY ORACLE;                                                                                                                                                          
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = REFERRER_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE REFERRER_DIM (                                                                                                                                                                
    REFERRER_SK          NUMBER(13) NOT NULL,                                                                                                                                                           
    REFERRER_TXT         VARCHAR2(1332),                                                                                                                                                                
    REFERRER_DOMAIN_NM   VARCHAR2(165),                                                                                                                                                                 
    REFERRER_TYPE_CD     CHAR(1),                                                                                                                                                                       
    PRIMARY KEY (REFERRER_SK)                                                                                                                                                                           
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = REFERRER_QUERY_STRING_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                   
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE REFERRER_QUERY_STRING_DIM (                                                                                                                                                   
    REFERRER_QUERY_STRING_SK NUMBER(13) NOT NULL,                                                                                                                                                       
    REFERRER_QUERY_STRING_TXT VARCHAR2(1332),                                                                                                                                                           
    PRIMARY KEY (REFERRER_QUERY_STRING_SK)                                                                                                                                                              
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = SEARCH_ENGINE_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                           
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE SEARCH_ENGINE_DIM (                                                                                                                                                           
    SEARCH_ENGINE_SK     NUMBER(13) NOT NULL,                                                                                                                                                           
    SEARCH_ENGINE_DOMAIN_TXT VARCHAR2(165),                                                                                                                                                             
    SEARCH_ENGINE_DESC   VARCHAR2(130),                                                                                                                                                                 
    PRIMARY KEY (SEARCH_ENGINE_SK)                                                                                                                                                                      
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = SEARCH_RESULTS or %upcase(&tblnm) = ALL %then %do;                                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE SEARCH_RESULTS (                                                                                                                                                              
    SEARCH_RESULTS_SK    NUMBER(13) NOT NULL,                                                                                                                                                           
    DETAIL_SK            NUMBER(22),                                                                                                                                                                    
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    RESULTS_DISPLAYED_FLG CHAR(1),                                                                                                                                                                      
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    SESSION_ATTRIBUTION_SK NUMBER(19),                                                                                                                                                                  
    SEARCH_NM            VARCHAR2(42),                                                                                                                                                                  
    SEARCH_RESULTS_DTTM  TIMESTAMP,                                                                                                                                                                     
    SEARCH_RESULTS_DISPLAYED NUMBER(9),                                                                                                                                                                 
    PRIMARY KEY (SEARCH_RESULTS_SK)                                                                                                                                                                     
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1SEARCH_RESULTS ON                                                                                                                                                         
    SEARCH_RESULTS( SESSION_SK )) BY ORACLE;                                                                                                                                                            
    EXECUTE (CREATE INDEX XIF2SEARCH_RESULTS ON                                                                                                                                                         
    SEARCH_RESULTS( DETAIL_SK )) BY ORACLE;                                                                                                                                                             
    EXECUTE (CREATE INDEX XIF4SEARCH_RESULTS ON                                                                                                                                                         
    SEARCH_RESULTS( SESSION_ATTRIBUTION_SK )) BY ORACLE;                                                                                                                                                
    EXECUTE (CREATE INDEX XIE1SEARCH_RESULTS ON                                                                                                                                                         
    SEARCH_RESULTS( LOAD_DTTM )) BY ORACLE;                                                                                                                                                             
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = SEARCH_TERM_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                             
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE SEARCH_TERM_DIM (                                                                                                                                                             
    SEARCH_TERM_SK       NUMBER(13) NOT NULL,                                                                                                                                                           
    SEARCH_TERM_TXT      VARCHAR2(1332),                                                                                                                                                                
    PRIMARY KEY (SEARCH_TERM_SK)                                                                                                                                                                        
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = SESSION_ACTIVITY_FACT or %upcase(&tblnm) = ALL %then %do;                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE SESSION_ACTIVITY_FACT (                                                                                                                                                       
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    ACTIVITY_DTTM        TIMESTAMP,                                                                                                                                                                     
    ACTIVITY_REFERENCE_KEY NUMBER(22),                                                                                                                                                                  
    ACTIVITY_DESC        VARCHAR2(1024),                                                                                                                                                                
    ACTIVITY_TYPE_CD     VARCHAR2(2),                                                                                                                                                                   
    ATTR_CHR_1_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_CHR_1_VAL       VARCHAR2(1024),                                                                                                                                                                
    ATTR_NUM_1_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_NUM_1_VAL       NUMBER(11),                                                                                                                                                                    
    ATTR_CHR_2_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_CHR_2_VAL       VARCHAR2(1024),                                                                                                                                                                
    ATTR_NUM_2_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_NUM_2_VAL       NUMBER(11),                                                                                                                                                                    
    ATTR_CHR_3_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_CHR_3_VAL       VARCHAR2(1024),                                                                                                                                                                
    ATTR_NUM_3_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_NUM_3_VAL       NUMBER(11),                                                                                                                                                                    
    ATTR_CHR_4_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_CHR_4_VAL       VARCHAR2(1024),                                                                                                                                                                
    ATTR_NUM_4_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_NUM_4_VAL       NUMBER(11),                                                                                                                                                                    
    ATTR_CHR_5_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_CHR_5_VAL       VARCHAR2(1024),                                                                                                                                                                
    ATTR_NUM_5_NM        VARCHAR2(40),                                                                                                                                                                  
    ATTR_NUM_5_VAL       NUMBER(11)                                                                                                                                                                     
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1SESSION_ACTIVITY_FACT ON                                                                                                                                                  
    SESSION_ACTIVITY_FACT( SESSION_SK )) BY ORACLE;                                                                                                                                                     
    EXECUTE (CREATE INDEX XIE1SESSION_ACTIVITY_FACT ON                                                                                                                                                  
    SESSION_ACTIVITY_FACT( ACTIVITY_TYPE_CD )) BY ORACLE;                                                                                                                                               
    EXECUTE (CREATE INDEX XIE2SESSION_ACTIVITY_FACT ON                                                                                                                                                  
    SESSION_ACTIVITY_FACT( ACTIVITY_DTTM )) BY ORACLE;                                                                                                                                                  
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = SESSION_ATTRIBUTION or %upcase(&tblnm) = ALL %then %do;                                                                                                                         
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE SESSION_ATTRIBUTION (                                                                                                                                                         
    SESSION_ATTRIBUTION_SK NUMBER(19) NOT NULL,                                                                                                                                                         
    CI_RESPONSE_SK       NUMBER(13),                                                                                                                                                                    
    DESTINATION_DETAIL_SK NUMBER(22),                                                                                                                                                                   
    DESTINATION_PAGE_SK  NUMBER(13),                                                                                                                                                                    
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    ORIGINATION_SK       NUMBER(13),                                                                                                                                                                    
    REFERRER_QUERY_STRING_SK NUMBER(13),                                                                                                                                                                
    REFERRER_SK          NUMBER(13),                                                                                                                                                                    
    SEARCH_ENGINE_SK     NUMBER(13),                                                                                                                                                                    
    SEARCH_TERM_SK       NUMBER(13),                                                                                                                                                                    
    SESSION_ATTRIBUTION_DTTM TIMESTAMP,                                                                                                                                                                 
    SESSION_SK           NUMBER(22),                                                                                                                                                                    
    SEQUENCE_NO          NUMBER(3),                                                                                                                                                                     
    PRIMARY KEY (SESSION_ATTRIBUTION_SK)                                                                                                                                                                
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( SESSION_SK )) BY ORACLE;                                                                                                                                                       
    EXECUTE (CREATE INDEX XIF3SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( REFERRER_SK )) BY ORACLE;                                                                                                                                                      
    EXECUTE (CREATE INDEX XIF4SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( ORIGINATION_SK )) BY ORACLE;                                                                                                                                                   
    EXECUTE (CREATE INDEX XIF5SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( REFERRER_QUERY_STRING_SK )) BY ORACLE;                                                                                                                                         
    EXECUTE (CREATE INDEX XIF6SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( SEARCH_ENGINE_SK )) BY ORACLE;                                                                                                                                                 
    EXECUTE (CREATE INDEX XIF7SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( SEARCH_TERM_SK )) BY ORACLE;                                                                                                                                                   
    EXECUTE (CREATE INDEX XIF9SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( DESTINATION_PAGE_SK )) BY ORACLE;                                                                                                                                              
    EXECUTE (CREATE INDEX XIF10SESSION_ATTRIBUTION ON                                                                                                                                                   
    SESSION_ATTRIBUTION( CI_RESPONSE_SK )) BY ORACLE;                                                                                                                                                   
    EXECUTE (CREATE INDEX XIF11SESSION_ATTRIBUTION ON                                                                                                                                                   
    SESSION_ATTRIBUTION( DESTINATION_DETAIL_SK )) BY ORACLE;                                                                                                                                            
    EXECUTE (CREATE INDEX XIE1SESSION_ATTRIBUTION ON                                                                                                                                                    
    SESSION_ATTRIBUTION( LOAD_DTTM )) BY ORACLE;                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = SESSION_FACT or %upcase(&tblnm) = ALL %then %do;                                                                                                                                
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE SESSION_FACT (                                                                                                                                                                
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    ACTIVE_SEC_SPENT_IN_SESSN_CNT NUMBER(11,3),                                                                                                                                                         
    BROWSER_SK           NUMBER(13),                                                                                                                                                                    
    CI_RESPONSE_SK       NUMBER(13),                                                                                                                                                                    
    CLIENT_SESSION_DT    DATE,                                                                                                                                                                          
    CLIENT_SESSION_START_DTTM TIMESTAMP,                                                                                                                                                                
    COOKIES_ENABLED_FLG  CHAR(1),                                                                                                                                                                       
    DEVICE_NM            VARCHAR2(85),                                                                                                                                                                  
    DEVICE_TYPE_NM       VARCHAR2(32),                                                                                                                                                                  
    ENTRY_PAGE_SK        NUMBER(13),                                                                                                                                                                    
    FLASH_ENABLED_FLG    CHAR(1),                                                                                                                                                                       
    FLASH_VERSION_NO     VARCHAR2(16),                                                                                                                                                                  
    GEO_IP_SK            NUMBER(13),                                                                                                                                                                    
    IP_ADDRESS           VARCHAR2(64),                                                                                                                                                                  
    JAVA_ENABLED_FLG     CHAR(1),                                                                                                                                                                       
    JAVA_SCRIPT_ENABLED_FLG CHAR(1),                                                                                                                                                                    
    JAVA_VERSION_NO      VARCHAR2(12),                                                                                                                                                                  
    LAST_SESSION_ACTIVITY_DTTM TIMESTAMP,                                                                                                                                                               
    LAST_USER_ID         VARCHAR2(52),                                                                                                                                                                  
    LOAD_DTTM            TIMESTAMP,                                                                                                                                                                     
    LOAD_COMPLETE_DTTM   TIMESTAMP,                                                                                                                                                                     
    NETWRK_DATA_TRANS_SEC_CNT NUMBER(11,3),                                                                                                                                                             
    NETWORK_DATA_VOLUME_BYTES_CNT NUMBER(9),                                                                                                                                                            
    ORIGINATION_SK       NUMBER(13),                                                                                                                                                                    
    PLATFORM_SK          NUMBER(13),                                                                                                                                                                    
    REFERRER_SK          NUMBER(13),                                                                                                                                                                    
    REFERRER_QUERY_STRING_SK NUMBER(13),                                                                                                                                                                
    SCREEN_COLOR_DEPTH_NO NUMBER(4),                                                                                                                                                                    
    SCREEN_SIZE_TXT      VARCHAR2(12),                                                                                                                                                                  
    SEARCH_ENGINE_SK     NUMBER(13),                                                                                                                                                                    
    SEARCH_TERM_SK       NUMBER(13),                                                                                                                                                                    
    SECONDS_SPENT_IN_SESSION_CNT NUMBER(11,3),                                                                                                                                                          
    SESSION_COMPLETE_FLG CHAR(1),                                                                                                                                                                       
    SESSION_DT           DATE NOT NULL,                                                                                                                                                                 
    SESSION_START_DTTM   TIMESTAMP,                                                                                                                                                                     
    PREV_SESSION_SK      NUMBER(22),                                                                                                                                                                    
    USER_AGENT_SK        NUMBER(13),                                                                                                                                                                    
    USER_DATA_VOLUME_BYTES_CNT NUMBER(9),                                                                                                                                                               
    USER_DATA_TRANS_SEC_CNT NUMBER(11,3),                                                                                                                                                               
    USER_LANGUAGE_CD     VARCHAR2(12),                                                                                                                                                                  
    VISITOR_ID           VARCHAR2(32),                                                                                                                                                                  
    PRIMARY KEY (SESSION_SK)                                                                                                                                                                            
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF5SESSION_FACT ON                                                                                                                                                           
    SESSION_FACT( REFERRER_SK )) BY ORACLE;                                                                                                                                                             
    EXECUTE (CREATE INDEX XIF11SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( SESSION_DT )) BY ORACLE;                                                                                                                                                              
    EXECUTE (CREATE INDEX XIF12SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( SEARCH_TERM_SK )) BY ORACLE;                                                                                                                                                          
    EXECUTE (CREATE INDEX XIF4SESSION_FACT ON                                                                                                                                                           
    SESSION_FACT( ENTRY_PAGE_SK )) BY ORACLE;                                                                                                                                                           
    EXECUTE (CREATE INDEX XIF14SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( USER_AGENT_SK )) BY ORACLE;                                                                                                                                                           
    EXECUTE (CREATE INDEX XIF17SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( GEO_IP_SK )) BY ORACLE;                                                                                                                                                               
    EXECUTE (CREATE INDEX XIF18SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( REFERRER_QUERY_STRING_SK )) BY ORACLE;                                                                                                                                                
    EXECUTE (CREATE INDEX XIF19SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( SEARCH_ENGINE_SK )) BY ORACLE;                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF20SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( BROWSER_SK )) BY ORACLE;                                                                                                                                                              
    EXECUTE (CREATE INDEX XIF21SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( PLATFORM_SK )) BY ORACLE;                                                                                                                                                             
    EXECUTE (CREATE INDEX XIF22SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( ORIGINATION_SK )) BY ORACLE;                                                                                                                                                          
    EXECUTE (CREATE INDEX XIF23SESSION_FACT ON                                                                                                                                                          
    SESSION_FACT( CI_RESPONSE_SK )) BY ORACLE;                                                                                                                                                          
    EXECUTE (CREATE INDEX XIE2SESSION_FACT ON                                                                                                                                                           
    SESSION_FACT( LAST_SESSION_ACTIVITY_DTTM )) BY ORACLE;                                                                                                                                              
    EXECUTE (CREATE INDEX XIE3SESSION_FACT ON                                                                                                                                                           
    SESSION_FACT( SESSION_COMPLETE_FLG )) BY ORACLE;                                                                                                                                                    
    EXECUTE (CREATE INDEX XIE4SESSION_FACT ON                                                                                                                                                           
    SESSION_FACT( LOAD_DTTM )) BY ORACLE;                                                                                                                                                               
    EXECUTE (CREATE INDEX XIE5SESSION_FACT ON                                                                                                                                                           
    SESSION_FACT( LOAD_COMPLETE_DTTM )) BY ORACLE;                                                                                                                                                      
    EXECUTE (CREATE UNIQUE INDEX XAK1SESSION_FACT ON                                                                                                                                                    
    SESSION_FACT( SESSION_SK,SESSION_DT)) BY ORACLE;                                                                                                                                                    
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = SESSION_X_CUSTOMER or %upcase(&tblnm) = ALL %then %do;                                                                                                                          
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE SESSION_X_CUSTOMER (                                                                                                                                                          
    CUSTOMER_SK          NUMBER(13) NOT NULL,                                                                                                                                                           
    SESSION_SK           NUMBER(22) NOT NULL,                                                                                                                                                           
    VISITOR_ID           VARCHAR2(32),                                                                                                                                                                  
    INSERT_DTTM          TIMESTAMP,                                                                                                                                                                     
    PRIMARY KEY (CUSTOMER_SK, SESSION_SK)                                                                                                                                                               
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
    EXECUTE (CREATE INDEX XIF1SESSION_X_CUSTOMER ON                                                                                                                                                     
    SESSION_X_CUSTOMER( CUSTOMER_SK )) BY ORACLE;                                                                                                                                                       
    EXECUTE (CREATE INDEX XIF2SESSION_X_CUSTOMER ON                                                                                                                                                     
    SESSION_X_CUSTOMER( SESSION_SK )) BY ORACLE;                                                                                                                                                        
  %end;                                                                                                                                                                                                 
  %if %upcase(&tblnm) = USER_AGENT_DIM or %upcase(&tblnm) = ALL %then %do;                                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE USER_AGENT_DIM (                                                                                                                                                              
    USER_AGENT_SK        NUMBER(13) NOT NULL,                                                                                                                                                           
    USER_AGENT_NM        VARCHAR2(512),                                                                                                                                                                 
    PRIMARY KEY (USER_AGENT_SK)                                                                                                                                                                         
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end; 
	/* S0987696 Start */ 
  %if %upcase(&tblnm) = ETL_JOB_STATUS or %upcase(&tblnm) = ALL %then %do;                                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE ETL_JOB_STATUS (                                                                                                                                                              
    EVENT_NO               NUMERIC(8) ,
	LOAD_NO                NUMERIC(8),
	JOB_NAME               VARCHAR2(250),
	JOB_START_DATETIME 	   TIMESTAMP,
	JOB_END_DATETIME       TIMESTAMP,
	ETL_START_DATETIME     TIMESTAMP ,
	ETL_END_DATETIME       TIMESTAMP ,
	STATUS                 VARCHAR2(4000),
	RECORDS_LOADED         NUMERIC(8),
	ERROR_MSG              VARCHAR2(4000)                                                                                                                                                                      
    )) BY ORACLE;                                                                                                                                                                                       
                                                                                                                                                                                                        
  %end;    
  %if %upcase(&tblnm) = ETL_JOB_STATUS_HISTORY or %upcase(&tblnm) = ALL %then %do;                                                                                                                              
                                                                                                                                                                                                        
    EXECUTE (CREATE TABLE ETL_JOB_STATUS_HISTORY (                                                                                                                                                              
    EVENT_NO                NUMERIC(8) ,
	LOAD_NO                 NUMERIC(8),
	JOB_NAME                VARCHAR2(250),
	JOB_START_DATETIME      TIMESTAMP,
	JOB_END_DATETIME        TIMESTAMP,
	ETL_START_DATETIME      TIMESTAMP ,
	ETL_END_DATETIME        TIMESTAMP ,
	STATUS                  VARCHAR2(4000),
	RECORDS_LOADED          NUMERIC(8),
	ERROR_MSG               VARCHAR2(4000)                                                                                                                                                           
	)) BY ORACLE;                                                                                                                                                                                     
  %end;  
	/* S0987696 End */ 
    disconnect from oracle;
  quit;
%mend;
